==> abiword_0.7.7.orig.tar.gz: abiword-0.7.7.orig/wv/iconv/iconv_internal.h <==
U16 wvConvert932ToUnicode(U16 char8);
U16 wvConvert936ToUnicode(U16 char8);
U16 wvConvert949ToUnicode(U16 char8);
U16 wvConvert950ToUnicode(U16 char8);

size_t wvConvert874ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert874ToUnicode(U16 char8);
size_t wvConvert1250ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1250ToUnicode(U16 char8);
size_t wvConvert1251ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1251ToUnicode(U16 char8);
size_t wvConvert1252ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1252ToUnicode(U16 char8);
size_t wvConvert1253ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1253ToUnicode(U16 char8);
size_t wvConvert1254ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1254ToUnicode(U16 char8);
size_t wvConvert1255ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1255ToUnicode(U16 char8);
size_t wvConvert1256ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1256ToUnicode(U16 char8);
size_t wvConvert1257ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1257ToUnicode(U16 char8);

size_t wvConvertUnicodeToiso8859_15(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 ConvertUnicodeToiso8859_15(U16 char16);
size_t wvConvertUnicodeToKOI8_R(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 ConvertUnicodeToKOI8_R(U16 char16);
size_t wvConvertUnicodeToTIS620(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 ConvertUnicodeToTIS620(U16 char16);
size_t wvConvertUnicodeToUTF_8(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);

==> abiword-1.0.2.tar.gz: abiword-1.0.2/wv/iconv/iconv_internal.h <==
U16 wvConvert932ToUnicode(U16 char8);
U16 wvConvert936ToUnicode(U16 char8);
U16 wvConvert949ToUnicode(U16 char8);
U16 wvConvert950ToUnicode(U16 char8);

size_t wvConvert874ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert874ToUnicode(U16 char8);
size_t wvConvert1250ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1250ToUnicode(U16 char8);
size_t wvConvert1251ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1251ToUnicode(U16 char8);
size_t wvConvert1252ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1252ToUnicode(U16 char8);
size_t wvConvert1253ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1253ToUnicode(U16 char8);
size_t wvConvert1254ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1254ToUnicode(U16 char8);
size_t wvConvert1255ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1255ToUnicode(U16 char8);
size_t wvConvert1256ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1256ToUnicode(U16 char8);
size_t wvConvert1257ToUnicode(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 Convert1257ToUnicode(U16 char8);

size_t wvConvertUnicodeToiso8859_15(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 ConvertUnicodeToiso8859_15(U16 char16);
size_t wvConvertUnicodeToKOI8_R(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 ConvertUnicodeToKOI8_R(U16 char16);
size_t wvConvertUnicodeToTIS620(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
U16 ConvertUnicodeToTIS620(U16 char16);
size_t wvConvertUnicodeToUTF_8(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
size_t wvConvertUnicodeToUCS_2(const char **inbuf, size_t *inbytesleft, char **outbuf, size_t *outbytesleft);
